@@ -1,14 +1,8 @@
-"""
-    weasyprint.tests.layout.footnotes
-    ---------------------------------
-
-    Tests for footnotes layout.
-
-"""
+"""Tests for footnotes layout."""
 
 import pytest
 
-from ..testing_utils import assert_no_logs, render_pages
+from ..testing_utils import assert_no_logs, render_pages, tree_position
 
 
 @assert_no_logs
@@ -162,8 +156,6 @@ def test_several_footnote():
                 font-family: weasyprint;
                 font-size: 2px;
                 line-height: 1;
-                orphans: 1;
-                widows: 1;
             }
             span {
                 float: footnote;
@@ -210,8 +202,6 @@ def test_reported_footnote_1():
                 font-family: weasyprint;
                 font-size: 2px;
                 line-height: 1;
-                orphans: 1;
-                widows: 1;
             }
             span {
                 float: footnote;
@@ -255,8 +245,6 @@ def test_reported_footnote_2():
                 font-family: weasyprint;
                 font-size: 2px;
                 line-height: 1;
-                orphans: 1;
-                widows: 1;
             }
             span {
                 float: footnote;
@@ -302,8 +290,6 @@ def test_reported_footnote_3():
                 font-family: weasyprint;
                 font-size: 2px;
                 line-height: 1;
-                orphans: 1;
-                widows: 1;
             }
             span {
                 float: footnote;
@@ -338,6 +324,72 @@ def test_reported_footnote_3():
     assert footnote3.children[0].children[1].text == '3'
 
 
+@assert_no_logs
+def test_reported_sequential_footnote():
+    pages = render_pages('''
+        <style>
+            @font-face {src: url(weasyprint.otf); font-family: weasyprint}
+            @page {
+                size: 9px 7px;
+            }
+            div {
+                font-family: weasyprint;
+                font-size: 2px;
+                line-height: 1;
+            }
+            span {
+                float: footnote;
+            }
+        </style>
+        <div>
+            a<span>b</span><span>c</span><span>d</span><span>e</span>
+        </div>''')
+
+    positions = [
+        tree_position(pages, lambda box: getattr(box, 'text', None) == letter)
+        for letter in 'abcde']
+    assert sorted(positions) == positions
+
+
+@assert_no_logs
+@pytest.mark.parametrize('css, tail', (
+    ('p { break-inside: avoid }', '<br>e<br>f'),
+    ('p { widows: 4 }', '<br>e<br>f'),
+    ('p + p { break-before: avoid }', '</p><p>e<br>f'),
+    ('p + p { break-before: avoid }', '<span>y</span><span>z</span></p><p>e'),
+))
+def test_footnote_area_after_call(css, tail):
+    pages = render_pages('''
+        <style>
+            @font-face {src: url(weasyprint.otf); font-family: weasyprint}
+            @page {
+                size: 9px 10px;
+                background: white;
+                margin: 0;
+            }
+            body {
+                font-family: weasyprint;
+                font-size: 2px;
+                line-height: 1;
+                orphans: 2;
+                widows: 2;
+                margin: 0;
+            }
+            span {
+                float: footnote;
+            }
+            %s
+        </style>
+        <div>a<br>b</div>
+        <p>c<br>d<span>x</span>%s</p>''' % (css, tail))
+
+    footnote_call = tree_position(
+        pages, lambda box: box.element_tag == 'p::footnote-call')
+    footnote_area = tree_position(
+        pages, lambda box: type(box).__name__ == 'FootnoteAreaBox')
+    assert footnote_call < footnote_area
+
+
 @assert_no_logs
 def test_footnote_display_inline():
     page, = render_pages('''
@@ -472,6 +524,8 @@ def test_footnote_policy_line():
                 font-family: weasyprint;
                 font-size: 2px;
                 line-height: 1;
+                orphans: 2;
+                widows: 2;
             }
             span {
                 float: footnote;
